diff --git a/eda-frontend/src/components/SchematicEditor/Header.js b/eda-frontend/src/components/SchematicEditor/Header.js
index 173474dde..e99195433 100644
--- a/eda-frontend/src/components/SchematicEditor/Header.js
+++ b/eda-frontend/src/components/SchematicEditor/Header.js
@@ -161,7 +161,7 @@ function Header (props) {
dispatch(setSchTitle(`${e.target.value}`))
}
- // handel notification snackbar open and close with message
+ // handle notification snackbar open and close with message
const [snacOpen, setSnacOpen] = React.useState(false)
const [message, setMessage] = React.useState('')
@@ -176,7 +176,7 @@ function Header (props) {
setSnacOpen(false)
}
- // handel schematic Share Dialog box
+ // handle schematic Share Dialog box
const [openShare, setShareOpen] = React.useState(false)
const handleShareOpen = () => {
@@ -219,7 +219,7 @@ function Header (props) {
}
}
- // handel display format of last saved status
+ // handle display format of last saved status
function getDate (jsonDate) {
const json = jsonDate
const date = new Date(json)
@@ -228,7 +228,7 @@ function Header (props) {
return `${day} ${month} ${hour}:${minute}:${second}`
}
- // handel Copy Share Url
+ // handle Copy Share Url
const textAreaRef = React.useRef(null)
function copyToClipboard (e) {
diff --git a/eda-frontend/src/pages/Login.js b/eda-frontend/src/pages/Login.js
index b4d925c8e..ff0061a82 100644
--- a/eda-frontend/src/pages/Login.js
+++ b/eda-frontend/src/pages/Login.js
@@ -168,7 +168,7 @@ export default function SignIn (props) {
onClick={handleClickShowPassword}
onMouseDown={handleMouseDownPassword}
>
- {showPassword ? : } {/* Handel password visibility */}
+ {showPassword ? : } {/* handle password visibility */}
diff --git a/eda-frontend/src/pages/signUp.js b/eda-frontend/src/pages/signUp.js
index 8ec8f3f9f..c5e6e219e 100644
--- a/eda-frontend/src/pages/signUp.js
+++ b/eda-frontend/src/pages/signUp.js
@@ -68,7 +68,7 @@ export default function SignUp () {
const handleMouseDownPassword = () => setShowPassword(!showPassword)
// Function call for google oAuth sign up.
- const handelGoogleSignup = () => {
+ const handleGoogleSignup = () => {
var host = window.location.protocol + '//' + window.location.host
dispatch(googleLogin(host))
}
@@ -146,7 +146,7 @@ export default function SignUp () {
onClick={handleClickShowPassword}
onMouseDown={handleMouseDownPassword}
>
- {showPassword ? : } {/* Handel password visibility */}
+ {showPassword ? : } {/* handle password visibility */}
)
@@ -178,7 +178,7 @@ export default function SignUp () {
fullWidth
variant="outlined"
color="primary"
- onClick={handelGoogleSignup}
+ onClick={handleGoogleSignup}
className={classes.submit}
>
Sign Up With Google
diff --git a/eda-frontend/src/redux/actions/actions.js b/eda-frontend/src/redux/actions/actions.js
index 9a42bff98..25f09b8d8 100644
--- a/eda-frontend/src/redux/actions/actions.js
+++ b/eda-frontend/src/redux/actions/actions.js
@@ -11,25 +11,25 @@ export const TOGGLE_COLLAPSE = 'TOGGLE_COLLAPSE'
export const FETCH_COMPONENTS = 'FETCH_COMPONENTS'
export const TOGGLE_SIMULATE = 'TOGGLE_SIMULATE'
-// Actions for handeling component properties
+// Actions for handleing component properties
export const GET_COMP_PROPERTIES = 'GET_COMP_PROPERTIES'
export const SET_COMP_PROPERTIES = 'SET_COMP_PROPERTIES'
export const CLOSE_COMP_PROPERTIES = 'CLOSE_COMP_PROPERTIES'
export const CLOSE_COMP_PROPERTIES_TEMP = 'CLOSE_COMP_PROPERTIES_TEMP'
-// Actions for handeling and generating netlist
+// Actions for handleing and generating netlist
export const SET_NETLIST = 'SET_NETLIST'
export const SET_TITLE = 'SET_TITLE'
export const SET_MODEL = 'SET_MODEL'
export const SET_CONTROL_LINE = 'SET_CONTROL_LINE'
export const SET_CONTROL_BLOCK = 'SET_CONTROL_BLOCK'
-// Actions for handeling simualtion result display
+// Actions for handleing simualtion result display
export const SET_RESULT_TITLE = 'SET_RESULT_TITLE'
export const SET_RESULT_GRAPH = 'SET_RESULT_GRAPH'
export const SET_RESULT_TEXT = 'SET_RESULT_TEXT'
-// Actions for handeling user authentication and registeration
+// Actions for handleing user authentication and registeration
export const USER_LOADING = 'USER_LOADING'
export const USER_LOADED = 'USER_LOADED'
export const LOGIN_SUCCESSFUL = 'LOGIN_SUCCESSFUL'
diff --git a/eda-frontend/src/redux/actions/componentPropertiesActions.js b/eda-frontend/src/redux/actions/componentPropertiesActions.js
index 13d75fffe..b96c240d2 100644
--- a/eda-frontend/src/redux/actions/componentPropertiesActions.js
+++ b/eda-frontend/src/redux/actions/componentPropertiesActions.js
@@ -24,7 +24,7 @@ export const setCompProperties = (id, compProperties) => (dispatch) => {
})
}
-// Handeling hiding of component properties sidebar
+// handleing hiding of component properties sidebar
export const closeCompProperties = () => (dispatch) => {
dispatch({
type: actions.CLOSE_COMP_PROPERTIES
diff --git a/eda-frontend/src/components/SchematicEditor/SchematicToolbar.js b/eda-frontend/src/components/SchematicEditor/SchematicToolbar.js
index 3a12ed346..ffdb08f1f 100644
--- a/eda-frontend/src/components/SchematicEditor/SchematicToolbar.js
+++ b/eda-frontend/src/components/SchematicEditor/SchematicToolbar.js
@@ -324,13 +324,13 @@ export default function SchematicToolbar ({ mobileClose, gridRef, ltiSimResult,
setHelpOpen(false)
}
// Handel Delete component
const handleDeleteComp = () => {
DeleteComp()
dispatch(closeCompProperties())
}
// Handel Notification Snackbar
const [snacOpen, setSnacOpen] = React.useState(false)
const [message, setMessage] = React.useState('')
@@ -466,8 +466,8 @@ export default function SchematicToolbar ({ mobileClose, gridRef, ltiSimResult,
}
}
- // Handel Save Schematic onCloud
- const handelSchSave = () => {
+ // handle Save Schematic onCloud
+ const handleSchSave = () => {
if (auth.isAuthenticated !== true) {
setMessage('You are not Logged In')
handleSnacClick()
@@ -503,7 +503,7 @@ export default function SchematicToolbar ({ mobileClose, gridRef, ltiSimResult,
}
// Save Schematics Locally
- const handelLocalSchSave = () => {
+ const handleLocalSchSave = () => {
const saveLocalData = {}
saveLocalData.data_dump = Save()
saveLocalData.title = schSave.title
@@ -524,7 +524,7 @@ export default function SchematicToolbar ({ mobileClose, gridRef, ltiSimResult,
}
// Open Locally Saved Schematic
- const handelLocalSchOpen = () => {
+ const handleLocalSchOpen = () => {
let obj = {}
const fileSelector = document.createElement('input')
fileSelector.setAttribute('type', 'file')
@@ -600,7 +600,7 @@ export default function SchematicToolbar ({ mobileClose, gridRef, ltiSimResult,
// Save - Ctrl + S
if (event.ctrlKey && event.keyCode === 83) {
event.preventDefault()
- handelSchSave()
+ handleSchSave()
}
// Print - Ctrl + P
if (event.ctrlKey && event.keyCode === 80) {
@@ -618,7 +618,7 @@ export default function SchematicToolbar ({ mobileClose, gridRef, ltiSimResult,
if (event.shiftKey) {
handleImgClickOpen()
} else {
- handelLocalSchSave()
+ handleLocalSchSave()
}
}
}
@@ -656,16 +656,16 @@ export default function SchematicToolbar ({ mobileClose, gridRef, ltiSimResult,
-
+
-
+
|
-
+
@@ -324,13 +324,13 @@ export default function SchematicToolbar ({ mobileClose, gridRef, ltiSimResult,
setHelpOpen(false)
}
- // Handel Delete component
+ // handle Delete component
const handleDeleteComp = () => {
DeleteComp()
@@ -324,13 +324,13 @@ export default function SchematicToolbar ({ mobileClose, gridRef, ltiSimResult,
dispatch(closeCompProperties())
}
- // Handel Notification Snackbar
+ // handle Notification Snackbar
const [snacOpen, setSnacOpen] = React.useState(false)
const [message, setMessage] = React.useState('')